==> cbol-1.5.tgz: cbol-1.5/s.php <==
<?php
 require("config.php");
 require("dbconfig.php");
 require("ref.php");
 require("code.php");
 require("lang.php");
 $ns=chr(34);
  /************* GET ܼ ***************/
  $N=$_REQUEST['N'];//d 0Gs 1:¬
  $k=$_REQUEST['k'];//d߽s

 /**** @ܼ ********/
  //W
 $PROGNAME="s.php";
 session_start();
 $strongfg=$_SESSION['strongfg'];
 //session_register("strongfg");
 if ($strongfg == 0) $strongfg = 1;
 $_SESSION['strongfg']=$strongfg;
 if ($N) //¬
 {
  $dictname="bdb";
  $dictname1="hfhl";
  $SNUM="hsnum";
  $SB="<a href=\"search.php?VERSION=unv&strongflag={$strongfg}&TABFLAG=1&orig=2";
  //require("font.php");

 }
 else //s
 {
  $dictname="thayer";
  $dictname1="gfhl";
  $SNUM="gsnum";
  $SB="<a href=\"search.php?VERSION=unv&strongflag={$strongfg}&TABFLAG=1&orig=1";
  //require("gfont.php");
 }
  $keyword=sprintf("%05d",$k);
  //QueryO
 $QUERY="select  $SNUM,txt from $dictname where $SNUM='$keyword'"; 
 if ($updatemode)
   $QUERY1="select  $SNUM,txt,username from $dictname1 where $SNUM='$keyword'"; 
 else
 	$QUERY1="select  $SNUM,txt from $dictname1 where $SNUM='$keyword'"; 
  //TableXSOѼ
 $tabout="border=1";
  //Jܼ
  //d߸ƪY
 $THEADER=array("s","rq");
  //C@
 $PGNUM=50;
 // Primary Key	
 $PKEY="oid";
 $KEYCOLOR="\"#FF0000\"";
 $COLOR="\"#000000\"";
 
 $db_conn=db_connect("host=localhost dbname=$DBNAME");
 db_set_encoding($db_conn,"BIG5");
 /******** }ldƮw ********/
 $result=db_exec($db_conn,$QUERY);
 $result1=db_exec($db_conn,$QUERY1);
 echo "<body onLoad=\"javascript:focus()\">";
  if ($GBCODE==0)
        echo "<meta http-equiv=\"Content-Type\" CONTENT=\"text/html; charset=big5\">";
 else   
        echo "<meta http-equiv=\"Content-Type\" CONTENT=\"text/html; charset=gb2312\">";
 if (!$result){
                        echogb("Ʈwd߿~AO $QUERY !");
                        exit;
 }
 if (!$result1){
                        echogb("Ʈwd߿~AO $QUERY1 !");
                        exit;
 }
 $numrow=db_NumRows($result);  
 $numrow1=db_NumRows($result1);  
 /****** ȶȬOB˵ *********/
 if ($numrow>500)
   {
   	echogb("^r@ $numrow AƤӦhFAЭקd߱AdI");
	exit;
   }
 if ($numrow1>500)
   {
   	echogb("r@ $numrow AƤӦhFAЭקd߱AdI");
	exit;
   }
 if ($numrow==0)
   {
   	echogb("^rdơAЭקd߱AdI");
	exit;
   }
 if ($numrow1==0)
   {
   	echogb("rdơAЭקd߱AdI");
	exit;
   }
 /******** LX ********/
 echo "<FONT COLOR=$COLOR><center><table $tabout>\n";
      $ARAW=db_fetch_row($result,0); //Ū@O
      $ARAW1=db_fetch_row($result1,0); //Ū@O
	$SB=$SB."&keyword=$ARAW[0]\">X{g</a> <a href=\"$RETURNADD1\">d</a>";
      if ($updatemode)
        $special=htmlspecialchars($ARAW[0])." J̡G".$ARAW1[2];//SrBz
      else
        $special=htmlspecialchars($ARAW[0]);//SrBz
      echogb("<tr><td align=center>$special $SB</td></tr>\n"); //s
      $special=htmlspecialchars($ARAW[1]);//SrBz
      if (strlen($ARAW1[1])>0)
      {
      	$special1=htmlspecialchars($ARAW1[1]);//SrBz
      	$special1=$ARAW1[1];//SrBz
	$special1=hebtranpar(ref($special1,"Mt",1,$db_conn,"unv"),1);
	$special1=snref($special1,$db_conn);
	/***** Bz ****
	if (!(($pt=strpos($special1," "))===false))
        {
	    if (!(($pt1=strpos($special1,"{"))===false))
	    {
		$org=substr($special1,$pt,$pt1-$pt);
		$noorg=$org;
  		$org=ereg_replace("s([\r\n ])","{$ns}\\1",$org);
  		$org=ereg_replace("s$",$ns,$org);
		if ($N) $org=gfont($org);
		$special1=substr($special1,0,$pt).$org.substr($special1,$pt1);
	    }
        }
        **********/
      	echogb("<tr><td><pre>$special1</pre></td></tr>\n");
      }
      echogb("<tr><td><pre>$special</pre></td></tr>\n");
   echo "</table>\n";
   echogb("<a href=\"$RETURNADD1\">sd</a></center><br>\n");
   echo "</body>";
?>

==> cbol-1.7.tgz: cbol-1.7/s.php <==
<?php
 require("config.php");
 require("dbconfig.php");
 require("ref.php");
 require("code.php");
 require("lang.php");
 $ns=chr(34);
  /************* GET ܼ ***************/
  $N=(int) $_REQUEST['N'];//d 0Gs 1:¬
  $k=(int) $_REQUEST['k'];//d߽s

 /**** @ܼ ********/
  //W
 $PROGNAME="s.php";
 session_start();
 $strongfg=(int) $_SESSION['strongfg'];
 //session_register("strongfg");
 if ($strongfg == 0) $strongfg = 1;
 $_SESSION['strongfg']=$strongfg;
 if ($N) //¬
 {
  $dictname="bdb";
  $dictname1="hfhl";
  $SNUM="hsnum";
  $SB="<a href=\"search.php?VERSION=unv&strongflag={$strongfg}&TABFLAG=1&orig=2";
  //require("font.php");

 }
 else //s
 {
  $dictname="thayer";
  $dictname1="gfhl";
  $SNUM="gsnum";
  $SB="<a href=\"search.php?VERSION=unv&strongflag={$strongfg}&TABFLAG=1&orig=1";
  //require("gfont.php");
 }
  $keyword=sprintf("%05d",$k);
  //QueryO
 $QUERY="select  $SNUM,txt from $dictname where $SNUM='$keyword'"; 
 if ($updatemode)
   $QUERY1="select  $SNUM,txt,username from $dictname1 where $SNUM='$keyword'"; 
 else
 	$QUERY1="select  $SNUM,txt from $dictname1 where $SNUM='$keyword'"; 
  //TableXSOѼ
 $tabout="border=1";
  //Jܼ
  //d߸ƪY
 $THEADER=array("s","rq");
  //C@
 $PGNUM=50;
 // Primary Key	
 $PKEY="oid";
 $KEYCOLOR="\"#FF0000\"";
 $COLOR="\"#000000\"";
 
 $db_conn=db_connect("host=localhost dbname=$DBNAME");
 db_set_encoding($db_conn,"BIG5");
 /******** }ldƮw ********/
 $result=db_exec($db_conn,$QUERY);
 $result1=db_exec($db_conn,$QUERY1);
 echo "<body onLoad=\"javascript:focus()\">";
  if ($GBCODE==0)
        echo "<meta http-equiv=\"Content-Type\" CONTENT=\"text/html; charset=big5\">";
 else   
        echo "<meta http-equiv=\"Content-Type\" CONTENT=\"text/html; charset=gb2312\">";
 if (!$result){
                        echogb("Ʈwd߿~AO $QUERY !");
                        exit;
 }
 if (!$result1){
                        echogb("Ʈwd߿~AO $QUERY1 !");
                        exit;
 }
 $numrow=db_NumRows($result);  
 $numrow1=db_NumRows($result1);  
 /****** ȶȬOB˵ *********/
 if ($numrow>500)
   {
   	echogb("^r@ $numrow AƤӦhFAЭקd߱AdI");
	exit;
   }
 if ($numrow1>500)
   {
   	echogb("r@ $numrow AƤӦhFAЭקd߱AdI");
	exit;
   }
 if ($numrow==0)
   {
   	echogb("^rdơAЭקd߱AdI");
	exit;
   }
 if ($numrow1==0)
   {
   	echogb("rdơAЭקd߱AdI");
	exit;
   }
 /******** LX ********/
 echo "<FONT COLOR=$COLOR><center><table $tabout>\n";
      $ARAW=db_fetch_row($result,0); //Ū@O
      $ARAW1=db_fetch_row($result1,0); //Ū@O
	$SB=$SB."&keyword=$ARAW[0]\">X{g</a> <a href=\"$RETURNADD1\">d</a>";
      if ($updatemode)
        $special=htmlspecialchars($ARAW[0])." J̡G".$ARAW1[2];//SrBz
      else
        $special=htmlspecialchars($ARAW[0]);//SrBz
      echogb("<tr><td align=center>$special $SB</td></tr>\n"); //s
      $special=htmlspecialchars($ARAW[1]);//SrBz
      if (strlen($ARAW1[1])>0)
      {
      	$special1=htmlspecialchars($ARAW1[1]);//SrBz
      	$special1=$ARAW1[1];//SrBz
	$special1=hebtranpar(ref($special1,"Mt",1,$db_conn,"unv"),1);
	$special1=snref($special1,$db_conn);
	/***** Bz ****
	if (!(($pt=strpos($special1," "))===false))
        {
	    if (!(($pt1=strpos($special1,"{"))===false))
	    {
		$org=substr($special1,$pt,$pt1-$pt);
		$noorg=$org;
  		$org=ereg_replace("s([\r\n ])","{$ns}\\1",$org);
  		$org=ereg_replace("s$",$ns,$org);
		if ($N) $org=gfont($org);
		$special1=substr($special1,0,$pt).$org.substr($special1,$pt1);
	    }
        }
        **********/
      	echogb("<tr><td><pre>$special1</pre></td></tr>\n");
      }
      echogb("<tr><td><pre>$special</pre></td></tr>\n");
   echo "</table>\n";
   echogb("<a href=\"$RETURNADD1\">sd</a></center><br>\n");
   echo "</body>";
?>
